from pydantic import BaseModel
from controlresell_connector.com.controlresell.connector.models.jobs.orders.JobOrder import JobOrder

class JobOrdersListResponse(BaseModel):
    orders: list[JobOrder]



from pydantic import BaseModel
from controlresell_connector.com.controlresell.connector.models.jobs.conversations.JobConversation import JobConversation

class JobConversationsGetResponse(BaseModel):
    conversation: JobConversation



from pydantic import BaseModel
from uuid import UUID
from controlresell_connector.com.controlresell.connector.models.jobs.auth.otp.JobAuthOtpPayload import JobAuthOtpPayload

class JobAuthOtpWithAccountPayload(BaseModel):
    accountId: UUID
    payload: JobAuthOtpPayload



from pydantic import BaseModel
from typing import Optional

class JobConversationsOffersUpdateResponse(BaseModel):
    transactionId: Optional[str] = None
    conversationId: str
    offerId: str
    accepted: bool



from pydantic import BaseModel
from uuid import UUID
from controlresell_connector.com.controlresell.connector.models.accounts.AccountPlatform import AccountPlatform

class WarmUp(BaseModel):
    id: UUID
    platform: AccountPlatform



from enum import Enum

class RabbitMQRoutingKey(str, Enum):
    AUTH_OTP = 'AUTH_OTP'
    AUTH_LOGIN = 'AUTH_LOGIN'
    AUTH_DATA = 'AUTH_DATA'
    ACCOUNTS_ACTIVITY = 'ACCOUNTS_ACTIVITY'
    POSTS_CREATE = 'POSTS_CREATE'
    POSTS_LIST = 'POSTS_LIST'
    POSTS_GET = 'POSTS_GET'
    POSTS_DELETE = 'POSTS_DELETE'
    POSTS_UPDATE = 'POSTS_UPDATE'
    POSTS_COMPLETION = 'POSTS_COMPLETION'
    ORDERS_LIST = 'ORDERS_LIST'
    ORDERS_LABELS_GET = 'ORDERS_LABELS_GET'
    ORDERS_LABELS_CREATE = 'ORDERS_LABELS_CREATE'
    CONVERSATIONS_INBOX_GET = 'CONVERSATIONS_INBOX_GET'
    CONVERSATIONS_GET = 'CONVERSATIONS_GET'
    CONVERSATIONS_MESSAGES_CREATE = 'CONVERSATIONS_MESSAGES_CREATE'
    CONVERSATIONS_OFFERS_CREATE = 'CONVERSATIONS_OFFERS_CREATE'
    CONVERSATIONS_OFFERS_UPDATE = 'CONVERSATIONS_OFFERS_UPDATE'



from pydantic import BaseModel
from controlresell_connector.com.controlresell.connector.models.jobs.posts.JobPostListed import JobPostListed

class JobPostsGetResponse(BaseModel):
    post: JobPostListed



from enum import Enum

class JobConversationMessageType(str, Enum):
    MESSAGE = 'MESSAGE'
    STATUS_MESSAGE = 'STATUS_MESSAGE'
    ACTION_MESSAGE = 'ACTION_MESSAGE'
    OFFER_REQUEST_MESSAGE = 'OFFER_REQUEST_MESSAGE'
    OFFER_MESSAGE = 'OFFER_MESSAGE'



from controlresell_connector.com.controlresell.connector.models.accounts.Account import Account
from controlresell_connector.com.controlresell.connector.models.accounts.AccountLabels import AccountLabels
from controlresell_connector.com.controlresell.connector.models.accounts.AccountPlatform import AccountPlatform
from controlresell_connector.com.controlresell.connector.models.accounts.CreateAccountPayload import CreateAccountPayload
from controlresell_connector.com.controlresell.connector.models.accounts.KubernetesStopRequest import KubernetesStopRequest
from controlresell_connector.com.controlresell.connector.models.accounts.UpdateAccountPayload import UpdateAccountPayload
from controlresell_connector.com.controlresell.connector.models.accounts.credentials.VintedCredentials import VintedCredentials
from controlresell_connector.com.controlresell.connector.models.application.ControlResellConnectorEnvironment import ControlResellConnectorEnvironment
from controlresell_connector.com.controlresell.connector.models.application.RabbitMQRoutingKey import RabbitMQRoutingKey
from controlresell_connector.com.controlresell.connector.models.jobs.GenericJobError import GenericJobError
from controlresell_connector.com.controlresell.connector.models.jobs.JobRequest import JobRequest
from controlresell_connector.com.controlresell.connector.models.jobs.JobResponseWebhook import JobResponseWebhook
from controlresell_connector.com.controlresell.connector.models.jobs.accounts.activity.JobAccountsHumanActivityPayload import JobAccountsHumanActivityPayload
from controlresell_connector.com.controlresell.connector.models.jobs.accounts.activity.JobAccountsHumanActivityResponse import JobAccountsHumanActivityResponse
from controlresell_connector.com.controlresell.connector.models.jobs.auth.data.JobAuthDataResponse import JobAuthDataResponse
from controlresell_connector.com.controlresell.connector.models.jobs.auth.data.UserAddress import UserAddress
from controlresell_connector.com.controlresell.connector.models.jobs.auth.login.JobAuthLoginError import JobAuthLoginError
from controlresell_connector.com.controlresell.connector.models.jobs.auth.login.JobAuthLoginPayload import JobAuthLoginPayload
from controlresell_connector.com.controlresell.connector.models.jobs.auth.login.JobAuthLoginResponse import JobAuthLoginResponse
from controlresell_connector.com.controlresell.connector.models.jobs.auth.otp.JobAuthOtpPayload import JobAuthOtpPayload
from controlresell_connector.com.controlresell.connector.models.jobs.auth.otp.JobAuthOtpResponse import JobAuthOtpResponse
from controlresell_connector.com.controlresell.connector.models.jobs.auth.otp.JobAuthOtpWithAccountPayload import JobAuthOtpWithAccountPayload
from controlresell_connector.com.controlresell.connector.models.jobs.conversations.JobConversation import JobConversation
from controlresell_connector.com.controlresell.connector.models.jobs.conversations.JobConversationOppositeUser import JobConversationOppositeUser
from controlresell_connector.com.controlresell.connector.models.jobs.conversations.JobConversationTransaction import JobConversationTransaction
from controlresell_connector.com.controlresell.connector.models.jobs.conversations.JobConversationUserRole import JobConversationUserRole
from controlresell_connector.com.controlresell.connector.models.jobs.conversations.get.JobConversationsGetPayload import JobConversationsGetPayload
from controlresell_connector.com.controlresell.connector.models.jobs.conversations.get.JobConversationsGetResponse import JobConversationsGetResponse
from controlresell_connector.com.controlresell.connector.models.jobs.conversations.inbox.JobConversationInbox import JobConversationInbox
from controlresell_connector.com.controlresell.connector.models.jobs.conversations.inbox.JobConversationInboxOppositeUser import JobConversationInboxOppositeUser
from controlresell_connector.com.controlresell.connector.models.jobs.conversations.inbox.get.JobConversationsInboxGetPayload import JobConversationsInboxGetPayload
from controlresell_connector.com.controlresell.connector.models.jobs.conversations.inbox.get.JobConversationsInboxGetResponse import JobConversationsInboxGetResponse
from controlresell_connector.com.controlresell.connector.models.jobs.conversations.messages.JobConversationMessage import JobConversationMessage
from controlresell_connector.com.controlresell.connector.models.jobs.conversations.messages.JobConversationMessageOffer import JobConversationMessageOffer
from controlresell_connector.com.controlresell.connector.models.jobs.conversations.messages.JobConversationMessageOfferStatus import JobConversationMessageOfferStatus
from controlresell_connector.com.controlresell.connector.models.jobs.conversations.messages.JobConversationMessageType import JobConversationMessageType
from controlresell_connector.com.controlresell.connector.models.jobs.conversations.messages.create.JobConversationsMessagesCreatePayload import JobConversationsMessagesCreatePayload
from controlresell_connector.com.controlresell.connector.models.jobs.conversations.messages.create.JobConversationsMessagesCreateResponse import JobConversationsMessagesCreateResponse
from controlresell_connector.com.controlresell.connector.models.jobs.conversations.offers.JobConversationOffer import JobConversationOffer
from controlresell_connector.com.controlresell.connector.models.jobs.conversations.offers.create.JobConversationsOffersCreatePayload import JobConversationsOffersCreatePayload
from controlresell_connector.com.controlresell.connector.models.jobs.conversations.offers.create.JobConversationsOffersCreateResponse import JobConversationsOffersCreateResponse
from controlresell_connector.com.controlresell.connector.models.jobs.conversations.offers.update.JobConversationsOffersUpdatePayload import JobConversationsOffersUpdatePayload
from controlresell_connector.com.controlresell.connector.models.jobs.conversations.offers.update.JobConversationsOffersUpdateResponse import JobConversationsOffersUpdateResponse
from controlresell_connector.com.controlresell.connector.models.jobs.orders.JobOrder import JobOrder
from controlresell_connector.com.controlresell.connector.models.jobs.orders.JobOrderStatus import JobOrderStatus
from controlresell_connector.com.controlresell.connector.models.jobs.orders.labels.create.JobOrdersLabelsCreatePayload import JobOrdersLabelsCreatePayload
from controlresell_connector.com.controlresell.connector.models.jobs.orders.labels.create.JobOrdersLabelsCreateResponse import JobOrdersLabelsCreateResponse
from controlresell_connector.com.controlresell.connector.models.jobs.orders.labels.get.JobOrdersLabelsGetPayload import JobOrdersLabelsGetPayload
from controlresell_connector.com.controlresell.connector.models.jobs.orders.labels.get.JobOrdersLabelsGetResponse import JobOrdersLabelsGetResponse
from controlresell_connector.com.controlresell.connector.models.jobs.orders.list.JobOrdersListPayload import JobOrdersListPayload
from controlresell_connector.com.controlresell.connector.models.jobs.orders.list.JobOrdersListResponse import JobOrdersListResponse
from controlresell_connector.com.controlresell.connector.models.jobs.posts.JobPost import JobPost
from controlresell_connector.com.controlresell.connector.models.jobs.posts.JobPostListed import JobPostListed
from controlresell_connector.com.controlresell.connector.models.jobs.posts.JobPostOptionals import JobPostOptionals
from controlresell_connector.com.controlresell.connector.models.jobs.posts.completion.JobPostsCompletionError import JobPostsCompletionError
from controlresell_connector.com.controlresell.connector.models.jobs.posts.completion.JobPostsCompletionPayload import JobPostsCompletionPayload
from controlresell_connector.com.controlresell.connector.models.jobs.posts.completion.JobPostsCompletionResponse import JobPostsCompletionResponse
from controlresell_connector.com.controlresell.connector.models.jobs.posts.create.JobPostsCreateError import JobPostsCreateError
from controlresell_connector.com.controlresell.connector.models.jobs.posts.create.JobPostsCreatePayload import JobPostsCreatePayload
from controlresell_connector.com.controlresell.connector.models.jobs.posts.create.JobPostsCreatePayloadWithAccounts import JobPostsCreatePayloadWithAccounts
from controlresell_connector.com.controlresell.connector.models.jobs.posts.create.JobPostsCreateResponse import JobPostsCreateResponse
from controlresell_connector.com.controlresell.connector.models.jobs.posts.delete.JobPostsDeletePayload import JobPostsDeletePayload
from controlresell_connector.com.controlresell.connector.models.jobs.posts.delete.JobPostsDeletePayloadList import JobPostsDeletePayloadList
from controlresell_connector.com.controlresell.connector.models.jobs.posts.delete.JobPostsDeleteResponse import JobPostsDeleteResponse
from controlresell_connector.com.controlresell.connector.models.jobs.posts.get.JobPostsGetPayload import JobPostsGetPayload
from controlresell_connector.com.controlresell.connector.models.jobs.posts.get.JobPostsGetResponse import JobPostsGetResponse
from controlresell_connector.com.controlresell.connector.models.jobs.posts.list.JobPostsListPayload import JobPostsListPayload
from controlresell_connector.com.controlresell.connector.models.jobs.posts.list.JobPostsListResponse import JobPostsListResponse
from controlresell_connector.com.controlresell.connector.models.jobs.posts.update.JobPostsUpdatePayload import JobPostsUpdatePayload
from controlresell_connector.com.controlresell.connector.models.jobs.posts.update.JobPostsUpdateResponse import JobPostsUpdateResponse
from controlresell_connector.com.controlresell.connector.models.warmup.CreateWarmUpPayload import CreateWarmUpPayload
from controlresell_connector.com.controlresell.connector.models.warmup.WarmUp import WarmUp



from pydantic import BaseModel
from uuid import UUID
from typing import Optional

class JobOrdersLabelsCreatePayload(BaseModel):
    accountId: UUID
    transactionId: Optional[str] = None
    conversationId: Optional[str] = None



from pydantic import BaseModel
from controlresell_connector.com.controlresell.connector.models.jobs.posts.delete.JobPostsDeletePayload import JobPostsDeletePayload

class JobPostsDeletePayloadList(BaseModel):
    payloads: list[JobPostsDeletePayload]



from pydantic import BaseModel
from controlresell_connector.com.controlresell.connector.models.accounts.AccountPlatform import AccountPlatform

class CreateWarmUpPayload(BaseModel):
    platform: AccountPlatform



from pydantic import BaseModel
from typing import Optional
from controlresell_connector.com.controlresell.connector.models.jobs.conversations.messages.JobConversationMessageOfferStatus import JobConversationMessageOfferStatus

class JobConversationMessageOffer(BaseModel):
    id: str
    transactionId: Optional[str] = None
    price: float
    originalPrice: float
    status: JobConversationMessageOfferStatus



from pydantic import BaseModel
from uuid import UUID
from controlresell_connector.com.controlresell.connector.models.jobs.conversations.messages.JobConversationMessage import JobConversationMessage

class JobConversationsMessagesCreateResponse(BaseModel):
    accountId: UUID
    messageId: UUID
    conversationId: str
    message: JobConversationMessage



from pydantic import BaseModel
from zodable_idschema import IdSchema
from controlresell_connector.com.controlresell.connector.models.jobs.posts.JobPost import JobPost

class JobPostsCreatePayload(BaseModel):
    itemId: IdSchema
    post: JobPost



from pydantic import BaseModel
from typing import Optional

class JobConversationTransaction(BaseModel):
    id: str
    status: int
    offlineVerification: Optional[bool] = None
    offerId: Optional[int] = None
    buyerId: Optional[int] = None
    sellerId: Optional[int] = None
    isCompleted: Optional[bool] = None
    shippingOrderId: Optional[int] = None
    availableActions: Optional[list[str]] = None
    currentUserSide: Optional[str] = None
    isBundle: Optional[bool] = None
    isReserved: Optional[bool] = None
    isPackageSizeSelected: Optional[bool] = None
    isBusinessSeller: Optional[bool] = None
    itemCount: Optional[int] = None
    itemId: Optional[str] = None
    itemIds: Optional[list[str]] = None
    itemTitle: Optional[str] = None
    itemUrl: Optional[str] = None
    itemIsClosed: Optional[bool] = None
    offerPriceAmount: Optional[str] = None
    offerPriceCurrency: Optional[str] = None
    serviceFeeAmount: Optional[str] = None
    serviceFeeCurrency: Optional[str] = None
    shipmentPriceAmount: Optional[str] = None
    shipmentPriceCurrency: Optional[str] = None
    totalWithoutShipmentAmount: Optional[str] = None
    totalWithoutShipmentCurrency: Optional[str] = None
    totalAmountWithoutTax: Optional[str] = None
    sellerItemCount: Optional[int] = None
    sellerCity: Optional[str] = None
    shipmentId: Optional[str] = None
    shipmentStatus: Optional[int] = None
    packageSizeCode: Optional[str] = None



from pydantic import BaseModel
from uuid import UUID
from typing import Optional

class JobConversationsMessagesCreatePayload(BaseModel):
    accountId: UUID
    messageId: UUID
    conversationId: str
    message: str
    photoUrl: Optional[list[str]] = None



from pydantic import BaseModel
from uuid import UUID
from typing import Optional

class JobOrdersLabelsCreateResponse(BaseModel):
    accountId: UUID
    transactionId: Optional[str] = None
    shipmentId: str



from pydantic import BaseModel
from typing import Optional
from controlresell_connector.com.controlresell.connector.models.jobs.conversations.messages.JobConversationMessageType import JobConversationMessageType
from controlresell_connector.com.controlresell.connector.models.jobs.conversations.messages.JobConversationMessageOffer import JobConversationMessageOffer
from datetime import datetime

class JobConversationMessage(BaseModel):
    id: str
    body: Optional[str] = None
    photos: Optional[list[str]] = None
    userId: Optional[str] = None
    isHidden: Optional[bool] = None
    type: JobConversationMessageType
    offer: Optional[JobConversationMessageOffer] = None
    createdAt: datetime
